;|
DXE.LSP
Michael Weaver
2175 George Road
Fairbanks, Alaska 99712
Email:71461.1775@compuserve.com
(907)488-3577
(c)1996 Michael Weaver

For Acad R12 only.

The are two routines contained in this file for dealing with
dimension extension lines, c:dxe and c:dse.

C:DXE will toggle dimension extension lines on and off for
a selected dimension.  Each pick of the dimension will step to
another combination of start on/off, end on/off settings.  Enter will
exit the routine.

C:DSE will swap dimension extension lines.  This is especially
useful for those dimensions with the dimension text outside the
extension lines but in the default position.  Unfortunately the
extension lines will not maintain their current on/off settings but
will be set per the current dimension variables.  Use C:DXE to
toggle them on and off.

Program notes:


dxe_defaults is a bitwise variable
  1	dimse1 on
  2	dimse2 on

Example dxe_defaults values

   value	dimse1		dimse2
   0		off		off
   1		on		off
   2		off		on
   3		on		on

|;


(defun c:dxe(;			Dimension eXtension Edit
  /;				no arguments
  dimse1;			value to restore
  dimse2;			value to restore
 );				end of local variable list

 (defun dxeerror(;	error handler to restore system variables
   msg;			error message
   /;			end of formal arguments
  );			end of local variable list
  (foreach var '("dimse1" "dimse2" "cmdecho")
   (if (read var) (setvar var (read var)))
  )
  (olderror msg)
 );			end dexerror

 (setq
  olderror *error*
  *error* dxeerror
  cmdecho (getvar "cmdecho")
  dimse1 (getvar "dimse1")
  dimse2 (getvar "dimse2")
 )
 (if dxe_defaults
  nil
  (setq dxe_defaults
   (+ dimse1 (* 2 dimse2))
  )
 );					end if
 (while (and
   (setq ent (entsel "\nSelect dimension: "))
   (setq
    elist (entget (car ent))
    temp (= "DIMENSION" (cdr (assoc 0 elist)))
   )
  );				end and
  (if (member (cdr (assoc 70 elist)) '(0 1 2 3 5 128 129 130 131 133))
   (progn
    (setq
     dxe_defaults (1+ dxe_defaults)
     dxe_defaults (if (< 3 dxe_defaults) 0 dxe_defaults)
    )
    (if (= 1 (logand dxe_defaults 1)) (setvar "dimse1" 1) (setvar "dimse1" 0))
    (if (= 2 (logand dxe_defaults 2)) (setvar "dimse2" 1) (setvar "dimse2" 0))
    (if (and
      (< 0 (getvar "cmdactive"))
      (= "DIM" (getvar "cmdnames"))
     )
     (command "update" ent "")
     (command "dim" "update" ent "" "e")
    );					end if dim command active?
   );					end progn
   (alert "Wrong type of dimension.")
  );					end if right type of dimension?
 );					end while
 (foreach var '("dimse1" "dimse2" "cmdecho")
  (if (read var) (setvar var (read var)))
 )
 (princ)
);					end c:dxe

(defun c:dse(;			dimension swap ends
  /;			no formal arguments
  ent;			dimension entity name and selection point
  dimlist;		dimension entity list
  elist;		modified dimension entity list
  en;			dimension entity name
  pt1;			first definition point
  pt2;			second definition point
 );			end of local variable list
 (while (setq ent (entsel))
  (if (= "DIMENSION" (cdr (assoc 0
      (setq dimlist (entget (car ent) '("acad")))
     );			end assoc
    );			end cdr
   );			end =
   (progn
    (if (member (cdr (assoc 70 dimlist)) '(0 1 2 3 5 128 129 130 131 133))
     (progn
      (setq
       en (car ent)
       pt1 (trans (cdr (assoc 13 dimlist)) en 1)
       pt2 (trans (cdr (assoc 14 dimlist)) en 1)
       elist (subst (cons 14 pt1) (assoc 14 dimlist) dimlist) 
       elist (subst (cons 13 pt2) (assoc 13 dimlist) elist) 
      )
      (entmod elist)
      (entupd en)
     );				end progn, it was a valid dimension
     (alert "Wrong type of dimension")
    );				end if valid dimension?
   );				end progn, it was a dimension
   (alert "Selected entity was not a dimension")
  );				end if a dimension?
 );				end while entities selected
 (princ);			end quietly
);				end c:dse
(progn
 (princ "\nc:dxe and c:dse by Michael Weaver 71461.1775@compuserve.com") 
 (princ)
);				end progn
